## dbt-tests-adapter 1.19.7 - March 03, 2026

### Features

- Add functional tests for `dbt.config.meta_get()` in Python models ([#1595](https://github.com/dbt-labs/dbt-adapters/issues/1595))

### Contributors
- [@venkaa28](https://github.com/venkaa28) ([#1595](https://github.com/dbt-labs/dbt-adapters/issues/1595))
